@@ -31,18 +31,22 @@ class Comment(models.Model):
         if not self.created:
             self.created = datetime.now()
 
+        # Render content and cache it into `content_html`
         if settings.COMMENTS_RENDER_METHOD == 'text':
+            html = self.content
             if settings.COMMENTS_URLIZE:
-                self.content_html = urlize(self.content)
-            self.content_html = linebreaks(self.content_html) 
+                html = urlize(html)
+            html = linebreaks(html)
         elif settings.COMMENTS_RENDER_METHOD == 'markdown':
-            self.content_html = markdown.markdown(
+            html = markdown.markdown(
                 self.content, safe_mode='escape') 
             # TODO: that is not work, some bug in urlize
             if settings.COMMENTS_URLIZE:
-                self.content_html = urlize(self.content_html)
+                html = urlize(html)
         else:
             raise Exception('Unknown render method')
+        self.content_html = html
+
         super(Comment, self).save(*args, **kwargs)
 
     def iter_children(self):
